@@ -9,6 +9,7 @@
 # import sys
 # sys.setrecursionlimit(n)
 
+from gooddata_metadata_client.model.api_entitlement import ApiEntitlement
 from gooddata_metadata_client.model.assignee_identifier import AssigneeIdentifier
 from gooddata_metadata_client.model.data_source_table_identifier import DataSourceTableIdentifier
 from gooddata_metadata_client.model.dataset_reference_identifier import DatasetReferenceIdentifier
@@ -16,7 +17,10 @@ from gooddata_metadata_client.model.declarative_analytical_dashboard import Decl
 from gooddata_metadata_client.model.declarative_analytics import DeclarativeAnalytics
 from gooddata_metadata_client.model.declarative_analytics_layer import DeclarativeAnalyticsLayer
 from gooddata_metadata_client.model.declarative_attribute import DeclarativeAttribute
+from gooddata_metadata_client.model.declarative_color_palette import DeclarativeColorPalette
 from gooddata_metadata_client.model.declarative_column import DeclarativeColumn
+from gooddata_metadata_client.model.declarative_csp_directive import DeclarativeCspDirective
+from gooddata_metadata_client.model.declarative_custom_application_setting import DeclarativeCustomApplicationSetting
 from gooddata_metadata_client.model.declarative_dashboard_plugin import DeclarativeDashboardPlugin
 from gooddata_metadata_client.model.declarative_data_source import DeclarativeDataSource
 from gooddata_metadata_client.model.declarative_data_source_permission import DeclarativeDataSourcePermission
@@ -34,9 +38,11 @@ from gooddata_metadata_client.model.declarative_organization_info import Declara
 from gooddata_metadata_client.model.declarative_organization_permission import DeclarativeOrganizationPermission
 from gooddata_metadata_client.model.declarative_pdm import DeclarativePdm
 from gooddata_metadata_client.model.declarative_reference import DeclarativeReference
+from gooddata_metadata_client.model.declarative_setting import DeclarativeSetting
 from gooddata_metadata_client.model.declarative_single_workspace_permission import DeclarativeSingleWorkspacePermission
 from gooddata_metadata_client.model.declarative_table import DeclarativeTable
 from gooddata_metadata_client.model.declarative_tables import DeclarativeTables
+from gooddata_metadata_client.model.declarative_theme import DeclarativeTheme
 from gooddata_metadata_client.model.declarative_user import DeclarativeUser
 from gooddata_metadata_client.model.declarative_user_group import DeclarativeUserGroup
 from gooddata_metadata_client.model.declarative_user_groups import DeclarativeUserGroups
@@ -51,12 +57,15 @@ from gooddata_metadata_client.model.declarative_workspace_hierarchy_permission i
 from gooddata_metadata_client.model.declarative_workspace_model import DeclarativeWorkspaceModel
 from gooddata_metadata_client.model.declarative_workspace_permissions import DeclarativeWorkspacePermissions
 from gooddata_metadata_client.model.declarative_workspaces import DeclarativeWorkspaces
+from gooddata_metadata_client.model.dependent_entities_graph import DependentEntitiesGraph
+from gooddata_metadata_client.model.dependent_entities_node import DependentEntitiesNode
+from gooddata_metadata_client.model.dependent_entities_request import DependentEntitiesRequest
+from gooddata_metadata_client.model.dependent_entities_response import DependentEntitiesResponse
+from gooddata_metadata_client.model.entitlements_request import EntitlementsRequest
+from gooddata_metadata_client.model.entity_identifier import EntityIdentifier
 from gooddata_metadata_client.model.generate_ldm_request import GenerateLdmRequest
 from gooddata_metadata_client.model.grain_identifier import GrainIdentifier
 from gooddata_metadata_client.model.granularities_formatting import GranularitiesFormatting
-from gooddata_metadata_client.model.inline_response200 import InlineResponse200
-from gooddata_metadata_client.model.inline_response200_options import InlineResponse200Options
-from gooddata_metadata_client.model.inline_response200_options_links import InlineResponse200OptionsLinks
 from gooddata_metadata_client.model.json_api_analytical_dashboard_in import JsonApiAnalyticalDashboardIn
 from gooddata_metadata_client.model.json_api_analytical_dashboard_in_attributes import JsonApiAnalyticalDashboardInAttributes
 from gooddata_metadata_client.model.json_api_analytical_dashboard_in_document import JsonApiAnalyticalDashboardInDocument
@@ -92,14 +101,47 @@ from gooddata_metadata_client.model.json_api_attribute_out_includes import JsonA
 from gooddata_metadata_client.model.json_api_attribute_out_list import JsonApiAttributeOutList
 from gooddata_metadata_client.model.json_api_attribute_out_relationships import JsonApiAttributeOutRelationships
 from gooddata_metadata_client.model.json_api_attribute_out_relationships_dataset import JsonApiAttributeOutRelationshipsDataset
+from gooddata_metadata_client.model.json_api_attribute_out_relationships_default_view import JsonApiAttributeOutRelationshipsDefaultView
 from gooddata_metadata_client.model.json_api_attribute_out_with_links import JsonApiAttributeOutWithLinks
 from gooddata_metadata_client.model.json_api_attribute_to_many_linkage import JsonApiAttributeToManyLinkage
 from gooddata_metadata_client.model.json_api_attribute_to_one_linkage import JsonApiAttributeToOneLinkage
+from gooddata_metadata_client.model.json_api_color_palette_in import JsonApiColorPaletteIn
+from gooddata_metadata_client.model.json_api_color_palette_in_attributes import JsonApiColorPaletteInAttributes
+from gooddata_metadata_client.model.json_api_color_palette_in_document import JsonApiColorPaletteInDocument
+from gooddata_metadata_client.model.json_api_color_palette_out import JsonApiColorPaletteOut
+from gooddata_metadata_client.model.json_api_color_palette_out_document import JsonApiColorPaletteOutDocument
+from gooddata_metadata_client.model.json_api_color_palette_out_list import JsonApiColorPaletteOutList
+from gooddata_metadata_client.model.json_api_color_palette_out_with_links import JsonApiColorPaletteOutWithLinks
+from gooddata_metadata_client.model.json_api_color_palette_patch import JsonApiColorPalettePatch
+from gooddata_metadata_client.model.json_api_color_palette_patch_attributes import JsonApiColorPalettePatchAttributes
+from gooddata_metadata_client.model.json_api_color_palette_patch_document import JsonApiColorPalettePatchDocument
 from gooddata_metadata_client.model.json_api_cookie_security_configuration_in import JsonApiCookieSecurityConfigurationIn
+from gooddata_metadata_client.model.json_api_cookie_security_configuration_in_attributes import JsonApiCookieSecurityConfigurationInAttributes
 from gooddata_metadata_client.model.json_api_cookie_security_configuration_in_document import JsonApiCookieSecurityConfigurationInDocument
 from gooddata_metadata_client.model.json_api_cookie_security_configuration_out import JsonApiCookieSecurityConfigurationOut
-from gooddata_metadata_client.model.json_api_cookie_security_configuration_out_attributes import JsonApiCookieSecurityConfigurationOutAttributes
 from gooddata_metadata_client.model.json_api_cookie_security_configuration_out_document import JsonApiCookieSecurityConfigurationOutDocument
+from gooddata_metadata_client.model.json_api_cookie_security_configuration_patch import JsonApiCookieSecurityConfigurationPatch
+from gooddata_metadata_client.model.json_api_cookie_security_configuration_patch_document import JsonApiCookieSecurityConfigurationPatchDocument
+from gooddata_metadata_client.model.json_api_csp_directive_in import JsonApiCspDirectiveIn
+from gooddata_metadata_client.model.json_api_csp_directive_in_attributes import JsonApiCspDirectiveInAttributes
+from gooddata_metadata_client.model.json_api_csp_directive_in_document import JsonApiCspDirectiveInDocument
+from gooddata_metadata_client.model.json_api_csp_directive_out import JsonApiCspDirectiveOut
+from gooddata_metadata_client.model.json_api_csp_directive_out_document import JsonApiCspDirectiveOutDocument
+from gooddata_metadata_client.model.json_api_csp_directive_out_list import JsonApiCspDirectiveOutList
+from gooddata_metadata_client.model.json_api_csp_directive_out_with_links import JsonApiCspDirectiveOutWithLinks
+from gooddata_metadata_client.model.json_api_csp_directive_patch import JsonApiCspDirectivePatch
+from gooddata_metadata_client.model.json_api_csp_directive_patch_attributes import JsonApiCspDirectivePatchAttributes
+from gooddata_metadata_client.model.json_api_csp_directive_patch_document import JsonApiCspDirectivePatchDocument
+from gooddata_metadata_client.model.json_api_custom_application_setting_in import JsonApiCustomApplicationSettingIn
+from gooddata_metadata_client.model.json_api_custom_application_setting_in_attributes import JsonApiCustomApplicationSettingInAttributes
+from gooddata_metadata_client.model.json_api_custom_application_setting_in_document import JsonApiCustomApplicationSettingInDocument
+from gooddata_metadata_client.model.json_api_custom_application_setting_out import JsonApiCustomApplicationSettingOut
+from gooddata_metadata_client.model.json_api_custom_application_setting_out_document import JsonApiCustomApplicationSettingOutDocument
+from gooddata_metadata_client.model.json_api_custom_application_setting_out_list import JsonApiCustomApplicationSettingOutList
+from gooddata_metadata_client.model.json_api_custom_application_setting_out_with_links import JsonApiCustomApplicationSettingOutWithLinks
+from gooddata_metadata_client.model.json_api_custom_application_setting_patch import JsonApiCustomApplicationSettingPatch
+from gooddata_metadata_client.model.json_api_custom_application_setting_patch_attributes import JsonApiCustomApplicationSettingPatchAttributes
+from gooddata_metadata_client.model.json_api_custom_application_setting_patch_document import JsonApiCustomApplicationSettingPatchDocument
 from gooddata_metadata_client.model.json_api_dashboard_plugin_in import JsonApiDashboardPluginIn
 from gooddata_metadata_client.model.json_api_dashboard_plugin_in_attributes import JsonApiDashboardPluginInAttributes
 from gooddata_metadata_client.model.json_api_dashboard_plugin_in_document import JsonApiDashboardPluginInDocument
@@ -115,37 +157,45 @@ from gooddata_metadata_client.model.json_api_data_source_identifier_out import J
 from gooddata_metadata_client.model.json_api_data_source_identifier_out_attributes import JsonApiDataSourceIdentifierOutAttributes
 from gooddata_metadata_client.model.json_api_data_source_identifier_out_document import JsonApiDataSourceIdentifierOutDocument
 from gooddata_metadata_client.model.json_api_data_source_identifier_out_list import JsonApiDataSourceIdentifierOutList
+from gooddata_metadata_client.model.json_api_data_source_identifier_out_meta import JsonApiDataSourceIdentifierOutMeta
 from gooddata_metadata_client.model.json_api_data_source_identifier_out_with_links import JsonApiDataSourceIdentifierOutWithLinks
 from gooddata_metadata_client.model.json_api_data_source_in import JsonApiDataSourceIn
 from gooddata_metadata_client.model.json_api_data_source_in_attributes import JsonApiDataSourceInAttributes
+from gooddata_metadata_client.model.json_api_data_source_in_attributes_parameters_inner import JsonApiDataSourceInAttributesParametersInner
 from gooddata_metadata_client.model.json_api_data_source_in_document import JsonApiDataSourceInDocument
 from gooddata_metadata_client.model.json_api_data_source_out import JsonApiDataSourceOut
 from gooddata_metadata_client.model.json_api_data_source_out_attributes import JsonApiDataSourceOutAttributes
 from gooddata_metadata_client.model.json_api_data_source_out_document import JsonApiDataSourceOutDocument
 from gooddata_metadata_client.model.json_api_data_source_out_list import JsonApiDataSourceOutList
-from gooddata_metadata_client.model.json_api_data_source_out_meta import JsonApiDataSourceOutMeta
 from gooddata_metadata_client.model.json_api_data_source_out_with_links import JsonApiDataSourceOutWithLinks
 from gooddata_metadata_client.model.json_api_data_source_patch import JsonApiDataSourcePatch
 from gooddata_metadata_client.model.json_api_data_source_patch_attributes import JsonApiDataSourcePatchAttributes
 from gooddata_metadata_client.model.json_api_data_source_patch_document import JsonApiDataSourcePatchDocument
 from gooddata_metadata_client.model.json_api_data_source_table_out import JsonApiDataSourceTableOut
 from gooddata_metadata_client.model.json_api_data_source_table_out_attributes import JsonApiDataSourceTableOutAttributes
-from gooddata_metadata_client.model.json_api_data_source_table_out_attributes_columns import JsonApiDataSourceTableOutAttributesColumns
+from gooddata_metadata_client.model.json_api_data_source_table_out_attributes_columns_inner import JsonApiDataSourceTableOutAttributesColumnsInner
 from gooddata_metadata_client.model.json_api_data_source_table_out_document import JsonApiDataSourceTableOutDocument
 from gooddata_metadata_client.model.json_api_data_source_table_out_list import JsonApiDataSourceTableOutList
 from gooddata_metadata_client.model.json_api_data_source_table_out_with_links import JsonApiDataSourceTableOutWithLinks
 from gooddata_metadata_client.model.json_api_dataset_linkage import JsonApiDatasetLinkage
 from gooddata_metadata_client.model.json_api_dataset_out import JsonApiDatasetOut
 from gooddata_metadata_client.model.json_api_dataset_out_attributes import JsonApiDatasetOutAttributes
-from gooddata_metadata_client.model.json_api_dataset_out_attributes_grain import JsonApiDatasetOutAttributesGrain
-from gooddata_metadata_client.model.json_api_dataset_out_attributes_reference_properties import JsonApiDatasetOutAttributesReferenceProperties
+from gooddata_metadata_client.model.json_api_dataset_out_attributes_grain_inner import JsonApiDatasetOutAttributesGrainInner
+from gooddata_metadata_client.model.json_api_dataset_out_attributes_reference_properties_inner import JsonApiDatasetOutAttributesReferencePropertiesInner
 from gooddata_metadata_client.model.json_api_dataset_out_document import JsonApiDatasetOutDocument
 from gooddata_metadata_client.model.json_api_dataset_out_includes import JsonApiDatasetOutIncludes
 from gooddata_metadata_client.model.json_api_dataset_out_list import JsonApiDatasetOutList
 from gooddata_metadata_client.model.json_api_dataset_out_relationships import JsonApiDatasetOutRelationships
+from gooddata_metadata_client.model.json_api_dataset_out_relationships_attributes import JsonApiDatasetOutRelationshipsAttributes
+from gooddata_metadata_client.model.json_api_dataset_out_relationships_facts import JsonApiDatasetOutRelationshipsFacts
 from gooddata_metadata_client.model.json_api_dataset_out_with_links import JsonApiDatasetOutWithLinks
 from gooddata_metadata_client.model.json_api_dataset_to_many_linkage import JsonApiDatasetToManyLinkage
 from gooddata_metadata_client.model.json_api_dataset_to_one_linkage import JsonApiDatasetToOneLinkage
+from gooddata_metadata_client.model.json_api_entitlement_out import JsonApiEntitlementOut
+from gooddata_metadata_client.model.json_api_entitlement_out_attributes import JsonApiEntitlementOutAttributes
+from gooddata_metadata_client.model.json_api_entitlement_out_document import JsonApiEntitlementOutDocument
+from gooddata_metadata_client.model.json_api_entitlement_out_list import JsonApiEntitlementOutList
+from gooddata_metadata_client.model.json_api_entitlement_out_with_links import JsonApiEntitlementOutWithLinks
 from gooddata_metadata_client.model.json_api_fact_linkage import JsonApiFactLinkage
 from gooddata_metadata_client.model.json_api_fact_out import JsonApiFactOut
 from gooddata_metadata_client.model.json_api_fact_out_attributes import JsonApiFactOutAttributes
@@ -162,7 +212,6 @@ from gooddata_metadata_client.model.json_api_filter_context_out_document import
 from gooddata_metadata_client.model.json_api_filter_context_out_includes import JsonApiFilterContextOutIncludes
 from gooddata_metadata_client.model.json_api_filter_context_out_list import JsonApiFilterContextOutList
 from gooddata_metadata_client.model.json_api_filter_context_out_relationships import JsonApiFilterContextOutRelationships
-from gooddata_metadata_client.model.json_api_filter_context_out_relationships_attributes import JsonApiFilterContextOutRelationshipsAttributes
 from gooddata_metadata_client.model.json_api_filter_context_out_with_links import JsonApiFilterContextOutWithLinks
 from gooddata_metadata_client.model.json_api_filter_context_patch import JsonApiFilterContextPatch
 from gooddata_metadata_client.model.json_api_filter_context_patch_document import JsonApiFilterContextPatchDocument
@@ -176,6 +225,7 @@ from gooddata_metadata_client.model.json_api_label_out_relationships import Json
 from gooddata_metadata_client.model.json_api_label_out_relationships_attribute import JsonApiLabelOutRelationshipsAttribute
 from gooddata_metadata_client.model.json_api_label_out_with_links import JsonApiLabelOutWithLinks
 from gooddata_metadata_client.model.json_api_label_to_many_linkage import JsonApiLabelToManyLinkage
+from gooddata_metadata_client.model.json_api_label_to_one_linkage import JsonApiLabelToOneLinkage
 from gooddata_metadata_client.model.json_api_metric_in import JsonApiMetricIn
 from gooddata_metadata_client.model.json_api_metric_in_attributes import JsonApiMetricInAttributes
 from gooddata_metadata_client.model.json_api_metric_in_attributes_content import JsonApiMetricInAttributesContent
@@ -186,7 +236,6 @@ from gooddata_metadata_client.model.json_api_metric_out_document import JsonApiM
 from gooddata_metadata_client.model.json_api_metric_out_includes import JsonApiMetricOutIncludes
 from gooddata_metadata_client.model.json_api_metric_out_list import JsonApiMetricOutList
 from gooddata_metadata_client.model.json_api_metric_out_relationships import JsonApiMetricOutRelationships
-from gooddata_metadata_client.model.json_api_metric_out_relationships_facts import JsonApiMetricOutRelationshipsFacts
 from gooddata_metadata_client.model.json_api_metric_out_with_links import JsonApiMetricOutWithLinks
 from gooddata_metadata_client.model.json_api_metric_patch import JsonApiMetricPatch
 from gooddata_metadata_client.model.json_api_metric_patch_attributes import JsonApiMetricPatchAttributes
@@ -203,6 +252,25 @@ from gooddata_metadata_client.model.json_api_organization_out_meta import JsonAp
 from gooddata_metadata_client.model.json_api_organization_out_relationships import JsonApiOrganizationOutRelationships
 from gooddata_metadata_client.model.json_api_organization_out_relationships_bootstrap_user import JsonApiOrganizationOutRelationshipsBootstrapUser
 from gooddata_metadata_client.model.json_api_organization_out_relationships_bootstrap_user_group import JsonApiOrganizationOutRelationshipsBootstrapUserGroup
+from gooddata_metadata_client.model.json_api_organization_patch import JsonApiOrganizationPatch
+from gooddata_metadata_client.model.json_api_organization_patch_document import JsonApiOrganizationPatchDocument
+from gooddata_metadata_client.model.json_api_organization_setting_in import JsonApiOrganizationSettingIn
+from gooddata_metadata_client.model.json_api_organization_setting_in_attributes import JsonApiOrganizationSettingInAttributes
+from gooddata_metadata_client.model.json_api_organization_setting_in_document import JsonApiOrganizationSettingInDocument
+from gooddata_metadata_client.model.json_api_organization_setting_out import JsonApiOrganizationSettingOut
+from gooddata_metadata_client.model.json_api_organization_setting_out_document import JsonApiOrganizationSettingOutDocument
+from gooddata_metadata_client.model.json_api_organization_setting_out_list import JsonApiOrganizationSettingOutList
+from gooddata_metadata_client.model.json_api_organization_setting_out_with_links import JsonApiOrganizationSettingOutWithLinks
+from gooddata_metadata_client.model.json_api_organization_setting_patch import JsonApiOrganizationSettingPatch
+from gooddata_metadata_client.model.json_api_organization_setting_patch_document import JsonApiOrganizationSettingPatchDocument
+from gooddata_metadata_client.model.json_api_theme_in import JsonApiThemeIn
+from gooddata_metadata_client.model.json_api_theme_in_document import JsonApiThemeInDocument
+from gooddata_metadata_client.model.json_api_theme_out import JsonApiThemeOut
+from gooddata_metadata_client.model.json_api_theme_out_document import JsonApiThemeOutDocument
+from gooddata_metadata_client.model.json_api_theme_out_list import JsonApiThemeOutList
+from gooddata_metadata_client.model.json_api_theme_out_with_links import JsonApiThemeOutWithLinks
+from gooddata_metadata_client.model.json_api_theme_patch import JsonApiThemePatch
+from gooddata_metadata_client.model.json_api_theme_patch_document import JsonApiThemePatchDocument
 from gooddata_metadata_client.model.json_api_user_group_in import JsonApiUserGroupIn
 from gooddata_metadata_client.model.json_api_user_group_in_document import JsonApiUserGroupInDocument
 from gooddata_metadata_client.model.json_api_user_group_in_relationships import JsonApiUserGroupInRelationships
@@ -227,15 +295,19 @@ from gooddata_metadata_client.model.json_api_user_out_list import JsonApiUserOut
 from gooddata_metadata_client.model.json_api_user_out_with_links import JsonApiUserOutWithLinks
 from gooddata_metadata_client.model.json_api_user_patch import JsonApiUserPatch
 from gooddata_metadata_client.model.json_api_user_patch_document import JsonApiUserPatchDocument
+from gooddata_metadata_client.model.json_api_user_setting_in import JsonApiUserSettingIn
+from gooddata_metadata_client.model.json_api_user_setting_in_document import JsonApiUserSettingInDocument
+from gooddata_metadata_client.model.json_api_user_setting_out import JsonApiUserSettingOut
+from gooddata_metadata_client.model.json_api_user_setting_out_document import JsonApiUserSettingOutDocument
+from gooddata_metadata_client.model.json_api_user_setting_out_list import JsonApiUserSettingOutList
+from gooddata_metadata_client.model.json_api_user_setting_out_with_links import JsonApiUserSettingOutWithLinks
 from gooddata_metadata_client.model.json_api_user_to_one_linkage import JsonApiUserToOneLinkage
 from gooddata_metadata_client.model.json_api_visualization_object_in import JsonApiVisualizationObjectIn
 from gooddata_metadata_client.model.json_api_visualization_object_in_document import JsonApiVisualizationObjectInDocument
 from gooddata_metadata_client.model.json_api_visualization_object_linkage import JsonApiVisualizationObjectLinkage
 from gooddata_metadata_client.model.json_api_visualization_object_out import JsonApiVisualizationObjectOut
 from gooddata_metadata_client.model.json_api_visualization_object_out_document import JsonApiVisualizationObjectOutDocument
-from gooddata_metadata_client.model.json_api_visualization_object_out_includes import JsonApiVisualizationObjectOutIncludes
 from gooddata_metadata_client.model.json_api_visualization_object_out_list import JsonApiVisualizationObjectOutList
-from gooddata_metadata_client.model.json_api_visualization_object_out_relationships import JsonApiVisualizationObjectOutRelationships
 from gooddata_metadata_client.model.json_api_visualization_object_out_with_links import JsonApiVisualizationObjectOutWithLinks
 from gooddata_metadata_client.model.json_api_visualization_object_patch import JsonApiVisualizationObjectPatch
 from gooddata_metadata_client.model.json_api_visualization_object_patch_document import JsonApiVisualizationObjectPatchDocument
@@ -276,11 +348,24 @@ from gooddata_metadata_client.model.json_api_workspace_out_meta_config import Js
 from gooddata_metadata_client.model.json_api_workspace_out_with_links import JsonApiWorkspaceOutWithLinks
 from gooddata_metadata_client.model.json_api_workspace_patch import JsonApiWorkspacePatch
 from gooddata_metadata_client.model.json_api_workspace_patch_document import JsonApiWorkspacePatchDocument
+from gooddata_metadata_client.model.json_api_workspace_setting_in import JsonApiWorkspaceSettingIn
+from gooddata_metadata_client.model.json_api_workspace_setting_in_document import JsonApiWorkspaceSettingInDocument
+from gooddata_metadata_client.model.json_api_workspace_setting_out import JsonApiWorkspaceSettingOut
+from gooddata_metadata_client.model.json_api_workspace_setting_out_document import JsonApiWorkspaceSettingOutDocument
+from gooddata_metadata_client.model.json_api_workspace_setting_out_list import JsonApiWorkspaceSettingOutList
+from gooddata_metadata_client.model.json_api_workspace_setting_out_with_links import JsonApiWorkspaceSettingOutWithLinks
+from gooddata_metadata_client.model.json_api_workspace_setting_patch import JsonApiWorkspaceSettingPatch
+from gooddata_metadata_client.model.json_api_workspace_setting_patch_document import JsonApiWorkspaceSettingPatchDocument
 from gooddata_metadata_client.model.json_api_workspace_to_one_linkage import JsonApiWorkspaceToOneLinkage
+from gooddata_metadata_client.model.label_identifier import LabelIdentifier
 from gooddata_metadata_client.model.list_links import ListLinks
 from gooddata_metadata_client.model.list_links_all_of import ListLinksAllOf
 from gooddata_metadata_client.model.object_links import ObjectLinks
 from gooddata_metadata_client.model.object_links_container import ObjectLinksContainer
+from gooddata_metadata_client.model.parameter import Parameter
+from gooddata_metadata_client.model.platform_usage import PlatformUsage
+from gooddata_metadata_client.model.platform_usage_request import PlatformUsageRequest
 from gooddata_metadata_client.model.reference_identifier import ReferenceIdentifier
+from gooddata_metadata_client.model.resolve_settings_request import ResolveSettingsRequest
 from gooddata_metadata_client.model.user_group_identifier import UserGroupIdentifier
 from gooddata_metadata_client.model.workspace_identifier import WorkspaceIdentifier
